@@ -6,8 +6,6 @@ Django models for training (both student and AI).
 from hashlib import sha1
 import json
 
-import six
-
 from django.core.cache import cache
 from django.db import models
 
@@ -58,7 +56,7 @@ class TrainingExample(models.Model):
 
         # This will raise `InvalidRubricSelection` if the selected options
         # do not match the rubric.
-        for criterion_name, option_name in six.iteritems(options_selected):
+        for criterion_name, option_name in options_selected.items():
             option = rubric.index.find_option(criterion_name, option_name)
             example.options_selected.add(option)
         return example
