@@ -10,7 +10,6 @@ from uuid import uuid4 as uuid
 import dateutil.parser
 import defusedxml.ElementTree as safe_etree
 import pytz
-import six
 
 import lxml.etree as etree
 from openassessment.xblock.data_conversion import update_assessments_format
@@ -59,7 +58,7 @@ def _safe_get_text(element):
     Returns:
         unicode
     """
-    return six.text_type(element.text) if element.text is not None else u""
+    return str(element.text) if element.text is not None else u""
 
 
 def _serialize_prompts(prompts_root, prompts_list):
@@ -82,7 +81,7 @@ def _serialize_prompts(prompts_root, prompts_list):
 
         # Prompt description
         prompt_description = etree.SubElement(prompt_el, 'description')
-        prompt_description.text = six.text_type(prompt.get('description', u''))
+        prompt_description.text = str(prompt.get('description', u''))
 
 
 def _serialize_options(options_root, options_list):
@@ -105,22 +104,22 @@ def _serialize_options(options_root, options_list):
         option_el = etree.SubElement(options_root, 'option')
 
         # Points (default to 0)
-        option_el.set('points', six.text_type(option.get('points', 0)))
+        option_el.set('points', str(option.get('points', 0)))
 
         # Name (default to a UUID)
         option_name = etree.SubElement(option_el, 'name')
         if 'name' in option:
-            option_name.text = six.text_type(option['name'])
+            option_name.text = str(option['name'])
         else:
-            option_name.text = six.text_type(uuid().hex)
+            option_name.text = str(uuid().hex)
 
         # Label (default to the option name, then an empty string)
         option_label = etree.SubElement(option_el, 'label')
-        option_label.text = six.text_type(option.get('label', option.get('name', u'')))
+        option_label.text = str(option.get('label', option.get('name', u'')))
 
         # Explanation (default to empty str)
         option_explanation = etree.SubElement(option_el, 'explanation')
-        option_explanation.text = six.text_type(option.get('explanation', u''))
+        option_explanation.text = str(option.get('explanation', u''))
 
 
 def _serialize_criteria(criteria_root, criteria_list):
@@ -146,17 +145,17 @@ def _serialize_criteria(criteria_root, criteria_list):
         # Criterion name (default to a UUID)
         criterion_name = etree.SubElement(criterion_el, u'name')
         if 'name' in criterion:
-            criterion_name.text = six.text_type(criterion['name'])
+            criterion_name.text = str(criterion['name'])
         else:
-            criterion_name.text = six.text_type(uuid().hex)
+            criterion_name.text = str(uuid().hex)
 
         # Criterion label (default to the name, then an empty string)
         criterion_label = etree.SubElement(criterion_el, 'label')
-        criterion_label.text = six.text_type(criterion.get('label', criterion.get('name', u'')))
+        criterion_label.text = str(criterion.get('label', criterion.get('name', u'')))
 
         # Criterion prompt (default to empty string)
         criterion_prompt = etree.SubElement(criterion_el, 'prompt')
-        criterion_prompt.text = six.text_type(criterion.get('prompt', u''))
+        criterion_prompt.text = str(criterion.get('prompt', u''))
 
         # Criterion feedback disabled, optional, or required
         # If disabled, do not set the attribute.
@@ -194,11 +193,11 @@ def serialize_rubric(rubric_root, oa_block):
 
     if oa_block.rubric_feedback_prompt is not None:
         feedback_prompt = etree.SubElement(rubric_root, 'feedbackprompt')
-        feedback_prompt.text = six.text_type(oa_block.rubric_feedback_prompt)
+        feedback_prompt.text = str(oa_block.rubric_feedback_prompt)
 
     if oa_block.rubric_feedback_default_text is not None:
         feedback_text = etree.SubElement(rubric_root, 'feedback_default_text')
-        feedback_text.text = six.text_type(oa_block.rubric_feedback_default_text)
+        feedback_text.text = str(oa_block.rubric_feedback_default_text)
 
 
 def parse_date(date_str, name=""):
@@ -223,9 +222,9 @@ def parse_date(date_str, name=""):
         return None
     try:
         # Get the date into ISO format
-        parsed_date = dateutil.parser.parse(six.text_type(date_str)).replace(tzinfo=pytz.utc)
+        parsed_date = dateutil.parser.parse(str(date_str)).replace(tzinfo=pytz.utc)
         formatted_date = parsed_date.strftime("%Y-%m-%dT%H:%M:%S")
-        return six.text_type(formatted_date)
+        return str(formatted_date)
     except (ValueError, TypeError):
         msg = (
             u'The format of the given date ({date}) for the {name} is invalid. '
@@ -499,8 +498,8 @@ def parse_examples_xml(examples):
                 raise UpdateFromXmlError(u'Each "select" element must have an "option" attribute')
 
             example_dict['options_selected'].append({
-                'criterion': six.text_type(select_el.get('criterion')),
-                'option': six.text_type(select_el.get('option'))
+                'criterion': str(select_el.get('criterion')),
+                'option': str(select_el.get('option'))
             })
 
         examples_list.append(example_dict)
@@ -530,7 +529,7 @@ def parse_assessments_xml(assessments_root):
 
         # Assessment name
         if 'name' in assessment.attrib:
-            assessment_dict['name'] = six.text_type(assessment.get('name'))
+            assessment_dict['name'] = str(assessment.get('name'))
         else:
             raise UpdateFromXmlError('All "assessment" elements must contain a "name" element.')
 
@@ -578,7 +577,7 @@ def parse_assessments_xml(assessments_root):
             # Staff assessment is the only type to use an explicit required marker
             if assessment_dict['name'] != 'staff-assessment':
                 raise UpdateFromXmlError('The "required" field is only allowed for staff assessment.')
-            assessment_dict['required'] = _parse_boolean(six.text_type(assessment.get('required')))
+            assessment_dict['required'] = _parse_boolean(str(assessment.get('required')))
 
         # Training examples
         examples = assessment.findall('example')
@@ -625,7 +624,7 @@ def serialize_training_examples(examples, assessment_el):
             for part in parts:
                 part_el = etree.SubElement(answer_el, 'part')
                 # pylint: disable=unicode-format-string
-                part_el.text = six.text_type(part.get('text', u''))
+                part_el.text = str(part.get('text', u''))
         except Exception:  # excuse the bare-except, looking for more information on EDUCATOR-1817
             log.exception(u'Error parsing training example: %s', example_dict)
             raise
@@ -634,8 +633,8 @@ def serialize_training_examples(examples, assessment_el):
         options_selected = example_dict.get('options_selected', [])
         for selected_dict in options_selected:
             select_el = etree.SubElement(example_el, 'select')
-            select_el.set('criterion', six.text_type(selected_dict.get('criterion', '')))
-            select_el.set('option', six.text_type(selected_dict.get('option', '')))
+            select_el.set('criterion', str(selected_dict.get('criterion', '')))
+            select_el.set('option', str(selected_dict.get('option', '')))
 
 
 def serialize_assessments(assessments_root, oa_block):
@@ -656,22 +655,22 @@ def serialize_assessments(assessments_root, oa_block):
         assessment = etree.SubElement(assessments_root, 'assessment')
 
         # Set assessment attributes, defaulting to empty values
-        assessment.set('name', six.text_type(assessment_dict.get('name', '')))
+        assessment.set('name', str(assessment_dict.get('name', '')))
 
         if 'must_grade' in assessment_dict:
-            assessment.set('must_grade', six.text_type(assessment_dict['must_grade']))
+            assessment.set('must_grade', str(assessment_dict['must_grade']))
 
         if 'must_be_graded_by' in assessment_dict:
-            assessment.set('must_be_graded_by', six.text_type(assessment_dict['must_be_graded_by']))
+            assessment.set('must_be_graded_by', str(assessment_dict['must_be_graded_by']))
 
         if assessment_dict.get('start') is not None:
-            assessment.set('start', six.text_type(assessment_dict['start']))
+            assessment.set('start', str(assessment_dict['start']))
 
         if assessment_dict.get('due') is not None:
-            assessment.set('due', six.text_type(assessment_dict['due']))
+            assessment.set('due', str(assessment_dict['due']))
 
         if assessment_dict.get('required') is not None:
-            assessment.set('required', six.text_type(assessment_dict['required']))
+            assessment.set('required', str(assessment_dict['required']))
 
         # Training examples
         examples = assessment_dict.get('examples', [])
@@ -696,34 +695,34 @@ def serialize_content_to_xml(oa_block, root):
 
     # Set the submission start date
     if oa_block.submission_start is not None:
-        root.set('submission_start', six.text_type(oa_block.submission_start))
+        root.set('submission_start', str(oa_block.submission_start))
 
     # Set submission due date
     if oa_block.submission_due is not None:
-        root.set('submission_due', six.text_type(oa_block.submission_due))
+        root.set('submission_due', str(oa_block.submission_due))
 
     # Set leaderboard show
     if oa_block.leaderboard_show:
-        root.set('leaderboard_show', six.text_type(oa_block.leaderboard_show))
+        root.set('leaderboard_show', str(oa_block.leaderboard_show))
 
     # Set text response
     if oa_block.text_response:
-        root.set('text_response', six.text_type(oa_block.text_response))
+        root.set('text_response', str(oa_block.text_response))
 
     # Set file upload response
     if oa_block.file_upload_response:
-        root.set('file_upload_response', six.text_type(oa_block.file_upload_response))
+        root.set('file_upload_response', str(oa_block.file_upload_response))
 
     # Set File upload settings
     if oa_block.file_upload_type:
-        root.set('file_upload_type', six.text_type(oa_block.file_upload_type))
+        root.set('file_upload_type', str(oa_block.file_upload_type))
 
     # Set File type white listing
     if oa_block.white_listed_file_types:
-        root.set('white_listed_file_types', six.text_type(oa_block.white_listed_file_types_string))
+        root.set('white_listed_file_types', str(oa_block.white_listed_file_types_string))
 
     if oa_block.allow_latex is not None:
-        root.set('allow_latex', six.text_type(oa_block.allow_latex))
+        root.set('allow_latex', str(oa_block.allow_latex))
 
     # Set group access setting if not empty
     if oa_block.group_access:
@@ -731,7 +730,7 @@ def serialize_content_to_xml(oa_block, root):
 
     # Open assessment displayed title
     title = etree.SubElement(root, 'title')
-    title.text = six.text_type(oa_block.title)
+    title.text = str(oa_block.title)
 
     # Assessment list
     assessments_root = etree.SubElement(root, 'assessments')
@@ -741,7 +740,7 @@ def serialize_content_to_xml(oa_block, root):
     prompts_root = etree.SubElement(root, 'prompts')
     _serialize_prompts(prompts_root, oa_block.prompts)
 
-    root.set('prompts_type', six.text_type(oa_block.prompts_type))
+    root.set('prompts_type', str(oa_block.prompts_type))
 
     # Rubric
     rubric_root = etree.SubElement(root, 'rubric')
@@ -845,37 +844,37 @@ def parse_from_xml(root):
     # Set it to None by default; we will update it to the latest start date later on
     submission_start = None
     if 'submission_start' in root.attrib:
-        submission_start = parse_date(six.text_type(root.attrib['submission_start']), name="submission start date")
+        submission_start = parse_date(str(root.attrib['submission_start']), name="submission start date")
 
     # Retrieve the due date for the submission
     # Set it to None by default; we will update it to the earliest deadline later on
     submission_due = None
     if 'submission_due' in root.attrib:
-        submission_due = parse_date(six.text_type(root.attrib['submission_due']), name="submission due date")
+        submission_due = parse_date(str(root.attrib['submission_due']), name="submission due date")
 
     text_response = None
     if 'text_response' in root.attrib:
-        text_response = six.text_type(root.attrib['text_response'])
+        text_response = str(root.attrib['text_response'])
 
     file_upload_response = None
     if 'file_upload_response' in root.attrib:
-        file_upload_response = six.text_type(root.attrib['file_upload_response'])
+        file_upload_response = str(root.attrib['file_upload_response'])
 
     allow_file_upload = None
     if 'allow_file_upload' in root.attrib:
-        allow_file_upload = _parse_boolean(six.text_type(root.attrib['allow_file_upload']))
+        allow_file_upload = _parse_boolean(str(root.attrib['allow_file_upload']))
 
     file_upload_type = None
     if 'file_upload_type' in root.attrib:
-        file_upload_type = six.text_type(root.attrib['file_upload_type'])
+        file_upload_type = str(root.attrib['file_upload_type'])
 
     white_listed_file_types = None
     if 'white_listed_file_types' in root.attrib:
-        white_listed_file_types = six.text_type(root.attrib['white_listed_file_types'])
+        white_listed_file_types = str(root.attrib['white_listed_file_types'])
 
     allow_latex = False
     if 'allow_latex' in root.attrib:
-        allow_latex = _parse_boolean(six.text_type(root.attrib['allow_latex']))
+        allow_latex = _parse_boolean(str(root.attrib['allow_latex']))
 
     group_access = {}
     if 'group_access' in root.attrib:
@@ -898,7 +897,7 @@ def parse_from_xml(root):
 
     prompts_type = 'text'
     if 'prompts_type' in root.attrib:
-        prompts_type = six.text_type(root.attrib['prompts_type'])
+        prompts_type = str(root.attrib['prompts_type'])
 
     # Retrieve the leaderboard if it exists, otherwise set it to 0
     leaderboard_show = 0
